django_openS3 — django_openS3 0.1.0 documentation

### Navigation

- index
- modules |
- next |
- django_openS3 0.1.0 documentation »

# django_openS3

An openS3 wrapper for use with Django.

# Installation

    $ pip install django_openS3

To install the latest development version:

    $ git clone git@github.com:logston/django_openS3.git
    $ cd django_openS3
    $ python setup.py install

# Usage

    # Add django_openS3 to your project's list of installed apps.
    INSTALLED_APPS = [
        ...
        'django_openS3',
        ...
    ]

    # Set your desired bucket and authentication/authorization info.
    AWS_STORAGE_BUCKET_NAME = os.environ['AWS_S3_BUCKET']
    AWS_ACCESS_KEY_ID = os.environ['AWS_S3_ACCESS_KEY']
    AWS_SECRET_ACCESS_KEY = os.environ['AWS_S3_SECRET_KEY']

    # Tell django to use django_openS3 for storing static files and media.
    DEFAULT_FILE_STORAGE = 'django_openS3.storage.S3MediaStorage'
    STATICFILES_STORAGE = 'django_openS3.storage.S3StaticStorage'

    # Optionally set the directories in which static and media
    # files will be saved to. Defaults are listed below.
    S3_STATIC_DIR = '/static/'
    S3_MEDIA_DIR = '/media/'

# Bug Tracker

Please report bugs!! Report bugs at django_openS3’s GitHub repo.

# Further Documentation

Further documentation can be found on Read the Docs.

# Contributions

Thanks for wanting to contribute! To contribute with development time, fork the repo logston/django_openS3 on GitHub and issue a pull request.

NB. To build the docs, you will need to set the following environment variables.

    DJANGO_SETTINGS_MODULE
    AWS_S3_BUCKET
    AWS_S3_ACCESS_KEY
    AWS_S3_SECRET_KEY

Set these environment variables to dummy values when building the docs just in case they some how sneak into the docs.

Contents:

- django_penS3 API
- Changelog
  - 0.1.0

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- django_openS3 0.1.0 documentation »